GeneralSystemDeviceLibraryAppBase class

UncompleteDocumentation

Implemented types
Implementers

Constructors

GeneralSystemDeviceLibraryAppBase()
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
screenshot_current_widget() → Future<Uint8List?>
UncompleteDocumentation
setFullScreen(bool isFullScreen) → Future<void>
UncompleteDocumentation
setPreferredOrientations({required List<GeneralSystemDeviceLibraryAppDeviceOrientationType> orientations}) → Future<void>
UncompleteDocumentation
showSnackBar({required String message}) → void
UncompleteDocumentation
toString() → String
A string representation of this object.
inherited
wake_lock_disable() → Future<void>
UncompleteDocumentation
wake_lock_enable() → Future<void>
UncompleteDocumentation
wake_lock_is_enabled() → Future<bool>
UncompleteDocumentation
wake_lock_toggle({required bool enable}) → Future<void>
UncompleteDocumentation

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

static_setFullScreen(bool isFullScreen) → Future<void>
UncompleteDocumentation
static_setPreferredOrientations({required List<GeneralSystemDeviceLibraryAppDeviceOrientationType> orientations}) → Future<void>
UncompleteDocumentation