GeneralSystemDeviceLibraryAudioBase class

UncompleteDocumentation

Implemented types

Constructors

GeneralSystemDeviceLibraryAudioBase()
UncompleteDocumentation

Properties

generalAudio → GeneralAudio
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRecordOrGetRecord({required String outputRecordFilePath, String? uniqueId, int? sampleRate}) → GeneralAudioRecorder
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
ensureInitialized() → FutureOr<void>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited