GeneralSystemDeviceLibraryBatteryBase class

UncompleteDocumentation

Implemented types
Implementers

Constructors

GeneralSystemDeviceLibraryBatteryBase()
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
is_save_mode → Future<bool>
UncompleteDocumentation
no setter
level → Future<int>
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status_realtime → Stream<BatteryStatusType>
UncompleteDocumentation
no setter
status_type → Future<BatteryStatusType>
UncompleteDocumentation
no setter

Methods

isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited