GeneralSystemDeviceLibraryNotificationBase class

UncompleteDocumentation

Implemented types
Implementers

Constructors

GeneralSystemDeviceLibraryNotificationBase()
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
is_support_awesome_notification → bool
UncompleteDocumentation
no setter
is_support_desktop_notification → bool
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSimpleNotification({required String title, required String text}) → Future<bool>
UncompleteDocumentation
initialize({String? defaultIcon, bool debug = false, String? languageCode}) → Future<bool>
UncompleteDocumentation
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited