GeneralSystemDeviceLibraryPlayerBase class

UncompleteDocumentation

Implemented types

Constructors

GeneralSystemDeviceLibraryPlayerBase()
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

containsPlayer({required String player_id}) → bool
UncompleteDocumentation
createPlayer({required String player_id}) → GeneralSystemDeviceLibraryPlayerControllerBase
UncompleteDocumentation
createPlayerWithoutAdd({required String player_id}) → GeneralSystemDeviceLibraryPlayerControllerBase
UncompleteDocumentation
ensureInitialized({String? libmpv}) → void
UncompleteDocumentation
getPlayer({required String player_id}) → GeneralSystemDeviceLibraryPlayerControllerBase?
UncompleteDocumentation
getPlayerForce({required String player_id}) → GeneralSystemDeviceLibraryPlayerControllerBase?
UncompleteDocumentation
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePlayer({required String player_id}) → Future<void>
UncompleteDocumentation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

players ↔ List<GeneralSystemDeviceLibraryPlayerControllerBase>
UncompleteDocumentation
getter/setter pair

Static Methods

staticEnsureInitialized({String? libmpv}) → void
UncompleteDocumentation