GeneralSystemDeviceLibrarySmsBase class

UncompleteDocumentation

Implemented types
Implementers

Constructors

GeneralSystemDeviceLibrarySmsBase()
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllSms() → Future<List<SmsMessageInfoData>>
UncompleteDocumentation
getAllThreads() → Future<List<SmsThreadInfoData>>
UncompleteDocumentation
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
querySms() → Future<List<SmsMessageInfoData>>
UncompleteDocumentation
queryThreads() → Future<List<SmsThreadInfoData>>
UncompleteDocumentation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited