SmsMessageInfoData class

UncompleteDocumentation

Constructors

SmsMessageInfoData({required int id, required int thread_id, required int sim, required String address, required String body, required bool read, required DateTime date, required DateTime date_sent})
UncompleteDocumentation

Properties

address ↔ String
UncompleteDocumentation
getter/setter pair
body ↔ String
UncompleteDocumentation
getter/setter pair
date ↔ DateTime
UncompleteDocumentation
getter/setter pair
date_sent ↔ DateTime
UncompleteDocumentation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
UncompleteDocumentation
getter/setter pair
read ↔ bool
UncompleteDocumentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sim ↔ int
UncompleteDocumentation
getter/setter pair
thread_id ↔ int
UncompleteDocumentation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
UncompleteDocumentation
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited