SmsThreadInfoData class

UncompleteDocumentation

Constructors

SmsThreadInfoData({required int id, required String address, required SmsContactInfoData contact, required List<SmsMessageInfoData> messages})
UncompleteDocumentation

Properties

address ↔ String
UncompleteDocumentation
getter/setter pair
contact ↔ SmsContactInfoData
UncompleteDocumentation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
UncompleteDocumentation
getter/setter pair
messages ↔ List<SmsMessageInfoData>
UncompleteDocumentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
UncompleteDocumentation
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited