GeneralSystemDeviceLibraryDeviceBaseFlutter class

Implemented types

Properties

android_is_development_mode_enable → Future<bool>
UncompleteDocumentation
no setteroverride
android_is_on_external_storage → Future<bool>
UncompleteDocumentation
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
is_desktop → bool
no setter
is_jailbroken → Future<bool>
UncompleteDocumentation
no setteroverride
is_mobile → bool
no setter
is_mock_location → Future<bool>
UncompleteDocumentation
no setteroverride
is_real_device → Future<bool>
UncompleteDocumentation
no setteroverride
is_safe_device → Future<bool>
UncompleteDocumentation
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usb_debug_check → Future<bool>
UncompleteDocumentation
no setteroverride

Methods

isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wake_lock_initizialized() → Future<void>
UncompleteDocumentation
override
wake_lock_is_enable() → Future<bool>
UncompleteDocumentation
override
wake_lock_toggle({required bool isEnable}) → Future<void>
UncompleteDocumentation
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

wake_lock_initizialized_static() → Future<void>
UncompleteDocumentation
override
wake_lock_is_enable_static() → Future<bool>
UncompleteDocumentation
override
wake_lock_toggle_static({required bool isEnable}) → Future<void>
UncompleteDocumentation
override