GeneralSystemDeviceLibraryPermissionBaseFlutter class

UncompleteDocumentation

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

auto_request({required List<PermissionType> permissionTypes}) → Future<void>
UncompleteDocumentation
override
flutter_auto_request({required List<Permission> permissions}) → Future<void>
UncompleteDocumentation
flutter_auto_request_all() → Future<void>
UncompleteDocumentation
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited