GeneralSystemDeviceLibrarySmsBaseFlutter class

UncompleteDocumentation

Implemented types

Properties

flutter_is_support_flutter_sms → bool
UncompleteDocumentation
no setter
hashCode → int
The hash code for this object.
no setterinherited
isAndroid → bool
UncompleteDocumentation
no setter
isIOS → bool
UncompleteDocumentation
no setter
isWeb → bool
UncompleteDocumentation
no setter
isWindows → bool
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get_threads() → Future<List>
UncompleteDocumentation
getAllSms() → Future<List<SmsMessageInfoData>>
UncompleteDocumentation
override
getAllThreads() → Future<List<SmsThreadInfoData>>
UncompleteDocumentation
override
isSupport() → bool
check is support or not
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
querySms() → Future<List<SmsMessageInfoData>>
UncompleteDocumentation
override
queryThreads() → Future<List<SmsThreadInfoData>>
UncompleteDocumentation
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited